summaryrefslogtreecommitdiffstats
path: root/WebCore/rendering/RootInlineBox.h
diff options
context:
space:
mode:
Diffstat (limited to 'WebCore/rendering/RootInlineBox.h')
-rw-r--r--WebCore/rendering/RootInlineBox.h11
1 files changed, 7 insertions, 4 deletions
diff --git a/WebCore/rendering/RootInlineBox.h b/WebCore/rendering/RootInlineBox.h
index 8c75072..4a0b485 100644
--- a/WebCore/rendering/RootInlineBox.h
+++ b/WebCore/rendering/RootInlineBox.h
@@ -69,8 +69,8 @@ public:
unsigned lineBreakPos() const { return m_lineBreakPos; }
void setLineBreakPos(unsigned p) { m_lineBreakPos = p; }
- int blockHeight() const { return m_blockHeight; }
- void setBlockHeight(int h) { m_blockHeight = h; }
+ int blockLogicalHeight() const { return m_blockLogicalHeight; }
+ void setBlockLogicalHeight(int h) { m_blockLogicalHeight = h; }
bool endsWithBreak() const { return m_endsWithBreak; }
void setEndsWithBreak(bool b) { m_endsWithBreak = b; }
@@ -88,6 +88,9 @@ public:
virtual void clearTruncation();
+ virtual int baselinePosition() const { return boxModelObject()->baselinePosition(m_firstLine, m_isVertical ? VerticalLine : HorizontalLine, PositionOfInteriorLineBoxes); }
+ virtual int lineHeight() const { return boxModelObject()->lineHeight(m_firstLine, m_isVertical ? VerticalLine : HorizontalLine, PositionOfInteriorLineBoxes); }
+
#if PLATFORM(MAC)
void addHighlightOverflow();
void paintCustomHighlight(PaintInfo&, int tx, int ty, const AtomicString& highlightType);
@@ -143,8 +146,8 @@ private:
// good for as long as the line has not been marked dirty.
OwnPtr<Vector<RenderBox*> > m_floats;
- // The height of the block at the end of this line. This is where the next line starts.
- int m_blockHeight;
+ // The logical height of the block at the end of this line. This is where the next line starts.
+ int m_blockLogicalHeight;
WTF::Unicode::Direction m_lineBreakBidiStatusEor : 5;
WTF::Unicode::Direction m_lineBreakBidiStatusLastStrong : 5;